yakumo.nova.v2.image

Package yakumo :: Package nova :: Package v2 :: Module image |
[hide private]
[frames] | no frames]

# Module image

source code

Resource class and its manager for images in Compute API v2

Classes | [hide private]
| Resource Resource class for images in Compute API v2
| Manager Manager class for images in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('size', 'O
      S-EXT-IMG-SIZE:size', mapper.Noop), ('min_ram', 'minRam', mapper.Noop)
      , ('min_disk', 'minDisk', mapper.Noop), ('metadata', 'metadata', mappe
      r.Noop), ('status', 'status', mapper.Noop), ('created_at', 'created',
      mapper.Noop), ('updated_at', 'updated', mapper.Noop),]